"use client";

import { useMemo } from "react";

import AutocompleteField from "./FormFields/autocomplete-field";
import CheckboxField from "./FormFields/checkbox-field";
// import CountryCodeAutocompleteField from "./FormFields/countries-fields/country-code-autocomplete-field";
import DateField from "./FormFields/date-field";
import DateTimeField from "./FormFields/date-time-field";
import InputField from "./FormFields/input-field";
import FormBuilder from "./form-builder";
import useFormBuilder from "./hooks/use-form-builder";
import prepareFields from "./utils/prepare-fields";
import Yup from "./utils/yup";

const FormBuilderExample = () => {
  const fields = useMemo(
    () =>
      prepareFields({
        name: {
          yup: Yup.string().required("Name is required"),
          type: "input",
          component: InputField,
          fieldsToWatch: ["name"],
          componentProps: ({ setValue, WatchValues }) => ({
            required: true,
            hidden: WatchValues.name,
            containerClassName: "col-span-12",
            onChange(value: any) {
              setValue("name", value);
            },
          }),
        },
        country: {
          yup: Yup.string().required("Country is required"),
          type: "autocomplete",
          component: AutocompleteField,
          componentProps: {
            required: true,
            containerClassName: "col-span-12",
            placeholder: "Select a country",
            options: [
              { value: "us", label: "United States" },
              { value: "uk", label: "United Kingdom" },
              { value: "ca", label: "Canada" },
            ],
          },
        },
        terms: {
          yup: Yup.boolean().oneOf([true], "You must accept the terms"),
          type: "checkbox",
          component: CheckboxField,
          componentProps: {
            required: true,
            label: "I accept the terms and conditions",
            containerClassName: "col-span-12",
          },
        },
        birthDate: {
          yup: Yup.date().required("Birth date is required"),
          type: "date",
          component: DateField,
          componentProps: {
            required: true,
            containerClassName: "col-span-12",
            placeholder: "Select birth date",
          },
        },

        meetingTime: {
          yup: Yup.date().required("Meeting time is required"),
          type: "datetime",
          component: DateTimeField,
          componentProps: {
            required: true,
            containerClassName: "col-span-12",
            placeholder: "Select meeting time",
          },
        },
        // phone_country_code: {
        //   yup: Yup.string().required("Phone country code is required"),
        //   type: "country-autocomplete",
        //   component: CountryCodeAutocompleteField,
        //   componentProps: {
        //     color: "#fff",
        //     required: true,
        //     variant: "under_line",
        //     containerClassName: "md:col-span-4",
        //     label: "Phone Country Code",
        //     getOptions: (country: any) => ({
        //       label: country.nameEn,
        //       value: `+${country.callingCode}`,
        //       key: country.alpha2Code,
        //       filterKeys: [country.callingCode, country.nameEn, country.nameAr],
        //       icon: country.flag,
        //     }),
        //   },
        // },
      }),
    []
  );

  const FormHooks = useFormBuilder(fields, {
    defaultValues: {
      name: "",
      country: "",
      terms: false,
      birthDate: undefined,
      meetingTime: undefined,
    },
  });

  return (
    <form
      onSubmit={FormHooks.handleSubmit((data) => {
        console.log(data);
      })}
    >
      <div className="grid grid-cols-12 gap-4">
        <div className="col-span-12">
          <FormBuilder fields={fields} FormHooks={FormHooks} />
        </div>
        <div className="col-span-12">
          <button
            type="submit"
            className="w-full rounded bg-blue-500 px-4 py-2 text-white hover:bg-blue-600"
          >
            {"Submit"}
          </button>
        </div>
      </div>
    </form>
  );
};

export default FormBuilderExample;
